Struct CdRom
Source #[repr(C, packed(1))]
pub struct CdRom {
pub header: DevicePathProtocol,
pub boot_entry: u32,
pub partition_start: u64,
pub partition_size: u64,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.