Struct RamDisk
Source #[repr(C, packed(1))]
pub struct RamDisk {
pub header: DevicePathProtocol,
pub starting_address: u64,
pub ending_address: u64,
pub disk_type: RamDiskType,
pub disk_instance: u16,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.