#[repr(transparent)]pub struct RamDiskType(pub Guid);Expand description
RAM disk type.
Tuple Fields
0: GuidImplementations
Sourceimpl RamDiskType
impl RamDiskType
Sourcepub const VIRTUAL_DISK: RamDiskType
pub const VIRTUAL_DISK: RamDiskType
RAM disk with a raw disk format in volatile memory.
Sourcepub const VIRTUAL_CD: RamDiskType
pub const VIRTUAL_CD: RamDiskType
RAM disk of an ISO image in volatile memory.
Sourcepub const PERSISTENT_VIRTUAL_DISK: RamDiskType
pub const PERSISTENT_VIRTUAL_DISK: RamDiskType
RAM disk with a raw disk format in persistent memory.
Sourcepub const PERSISTENT_VIRTUAL_CD: RamDiskType
pub const PERSISTENT_VIRTUAL_CD: RamDiskType
RAM disk of an ISO image in persistent memory.